@@ -237,12 +237,12 @@ void parentname2(char* result, int result_size, char* path)
     char* p;
 
     if(*path == 0) {
-        strncpy(result, "", result_size);
+        xstrncpy(result, "", result_size);
         return;
     }
     
     if(strcmp(path, "/") == 0) {
-        strncpy(result, "/", result_size);
+        xstrncpy(result, "/", result_size);
         return;
     }
 
@@ -256,7 +256,7 @@ void parentname2(char* result, int result_size, char* path)
         }
     }
 
-    strncpy(result, "", result_size);
+    xstrncpy(result, "", result_size);
 }
 
 
@@ -379,7 +379,7 @@ char* readline_file_completion_migemo_match(char* text, char* file)
     /// text側がfileの部分なら判定するまでも無くマッチ ///
     else if(same_point == strlen(text)) {
         char tmp[PATH_MAX];
-        strncpy(tmp, file, PATH_MAX);
+        xstrncpy(tmp, file, PATH_MAX);
         string_obj* tmp2 = STRING_NEW("");
         saphire_get_quoted_fname_readline_ver(tmp, tmp2);
         char* ret = strdup(string_c_str(tmp2));
@@ -453,7 +453,7 @@ char* readline_file_completion_migemo_match(char* text, char* file)
 
     if(r2 == 0) {
         char tmp[PATH_MAX];
-        strncpy(tmp, file, PATH_MAX);
+        xstrncpy(tmp, file, PATH_MAX);
         string_obj* tmp2 = STRING_NEW("");
         saphire_get_quoted_fname_readline_ver(tmp, tmp2);
         char* ret = strdup(string_c_str(tmp2));
@@ -570,8 +570,8 @@ char* readline_file_completion_migemo(const char* text, int rstat)
                         char buf[PATH_MAX];
 
                         struct stat _stat;
-                        strncpy(buf, string_c_str(gEditingDir), PATH_MAX);
-                        strncat(buf, entry->d_name, PATH_MAX);
+                        xstrncpy(buf, string_c_str(gEditingDir), PATH_MAX);
+                        xstrncat(buf, entry->d_name, PATH_MAX-1);
                         stat(buf, &_stat);
 
 #if defined(__DARWIN__)
@@ -580,24 +580,24 @@ char* readline_file_completion_migemo(const char* text, int rstat)
                         int des_size = strlen(src)*2;
                         char* des = MALLOC(des_size);
                         if(is_all_ascii(src)) {
-                            strncpy(des, src, des_size);
+                            xstrncpy(des, src, des_size);
                         }
                         else {
                             /// コンバート ///
                             if(kanji_convert(src, des, des_size, kUtf8Mac, kUtf8) < 0) {
-                                strncpy(des, src, des_size);
+                                xstrncpy(des, src, des_size);
                             }
                         }
-                        strncpy(buf, des, PATH_MAX);
+                        xstrncpy(buf, des, PATH_MAX);
 
                         FREE(des);
                         }
 #else
-                        strncpy(buf, entry->d_name, PATH_MAX);
+                        xstrncpy(buf, entry->d_name, PATH_MAX);
 #endif
 
                         if(S_ISDIR(_stat.st_mode)) {
-                            strncat(buf, "/", PATH_MAX);
+                            xstrncat(buf, "/", PATH_MAX-1);
                         }
 
                         vector_add(files, STRING_NEW(buf));
@@ -621,8 +621,8 @@ char* readline_file_completion_migemo(const char* text, int rstat)
                         char buf[PATH_MAX];
 
                         struct stat _stat;
-                        strncpy(buf, "./", PATH_MAX);
-                        strncat(buf, entry->d_name, PATH_MAX);
+                        xstrncpy(buf, "./", PATH_MAX);
+                        xstrncat(buf, entry->d_name, PATH_MAX-1);
                         stat(buf, &_stat);
 
 #if defined(__DARWIN__)
@@ -631,22 +631,22 @@ char* readline_file_completion_migemo(const char* text, int rstat)
                         int des_size = strlen(src)*2;
                         char* des = MALLOC(des_size);
                         if(is_all_ascii(src)) {
-                            strncpy(des, src, des_size);
+                            xstrncpy(des, src, des_size);
                         }
                         else {
                             /// コンバート ///
                             if(kanji_convert(src, des, des_size, kUtf8Mac, kUtf8) < 0) {
-                                strncpy(des, src, des_size);
+                                xstrncpy(des, src, des_size);
                             }
                         }
-                        strncpy(buf, des, PATH_MAX);
+                        xstrncpy(buf, des, PATH_MAX);
                         FREE(des);
                         }
 #else
-                        strncpy(buf, entry->d_name, PATH_MAX);
+                        xstrncpy(buf, entry->d_name, PATH_MAX);
 #endif
                         if(S_ISDIR(_stat.st_mode)) {
-                            strncat(buf, "/", PATH_MAX);
+                            xstrncat(buf, "/", PATH_MAX-1);
                         }
                         vector_add(files, STRING_NEW(buf));
                     }
@@ -666,7 +666,7 @@ char* readline_file_completion_migemo(const char* text, int rstat)
         /// ファイル名の入力がない補完は判定しなくても全てマッチ ///
         if(strcmp(text2, "") == 0) {
             char path[PATH_MAX];
-            strncpy(path, file, PATH_MAX);
+            xstrncpy(path, file, PATH_MAX);
 
             string_obj* tmp2 = STRING_NEW("");
             saphire_get_quoted_fname_readline_ver(path, tmp2);
@@ -674,8 +674,8 @@ char* readline_file_completion_migemo(const char* text, int rstat)
             string_delete(tmp2);
 
             struct stat stat_;
-            strncpy(path, string_c_str(gEditingDir), PATH_MAX);
-            strncat(path, file, PATH_MAX);
+            xstrncpy(path, string_c_str(gEditingDir), PATH_MAX);
+            xstrncat(path, file, PATH_MAX);
             if(stat(path, &stat_) == 0) {
                 if(S_ISDIR(stat_.st_mode)) {
                     rl_completion_append_character= 0;
@@ -698,15 +698,15 @@ char* readline_file_completion_migemo(const char* text, int rstat)
         else if(is_all_ascii((char*)text2) && is_all_ascii(file)) {
             if(!strncmp(text2, file, wordlen)) {
                 char path[PATH_MAX];
-                strncpy(path, file, PATH_MAX);
+                xstrncpy(path, file, PATH_MAX);
 
                 string_obj* tmp2 = STRING_NEW("");
                 saphire_get_quoted_fname(path, tmp2);
                 char* ret = strdup(string_c_str(tmp2));
                 string_delete(tmp2);
 
-                strncpy(path, string_c_str(gEditingDir), PATH_MAX);
-                strncat(path, file, PATH_MAX);
+                xstrncpy(path, string_c_str(gEditingDir), PATH_MAX);
+                xstrncat(path, file, PATH_MAX);
                 struct stat stat_;
                 if(stat(path, &stat_) == 0) {
                     if(S_ISDIR(stat_.st_mode)) {
@@ -732,8 +732,8 @@ char* readline_file_completion_migemo(const char* text, int rstat)
             if(ret) {
                 struct stat stat_;
                 char path[PATH_MAX];
-                strncpy(path, string_c_str(gEditingDir), PATH_MAX);
-                strncat(path, file, PATH_MAX);
+                xstrncpy(path, string_c_str(gEditingDir), PATH_MAX);
+                xstrncat(path, file, PATH_MAX);
                 if(stat(path, &stat_) == 0) {
                     if(S_ISDIR(stat_.st_mode)) {
                         rl_completion_append_character= 0;
@@ -803,20 +803,20 @@ char* readline_env_completion(const char* text, int stat)
             char* env2 = malloc(env2_size);
 
             if(*text == '$' && *(text+1) != '$') {
-                strncpy(env2, "$", env2_size);
-                strncat(env2, env, env2_size);
+                xstrncpy(env2, "$", env2_size);
+                xstrncat(env2, env, env2_size);
             }
             else if(*text == '$' && *(text+1) == '$') {
-                strncpy(env2, "$$", env2_size);
-                strncat(env2, env, env2_size);
+                xstrncpy(env2, "$$", env2_size);
+                xstrncat(env2, env, env2_size);
             }
             else if(*text == '@' && *(text+1) != '@') {
-                strncpy(env2, "@", env2_size);
-                strncat(env2, env, env2_size);
+                xstrncpy(env2, "@", env2_size);
+                xstrncat(env2, env, env2_size);
             }
             else if(*text == '@' && *(text+1) == '@') {
-                strncpy(env2, "@@", env2_size);
-                strncat(env2, env, env2_size);
+                xstrncpy(env2, "@@", env2_size);
+                xstrncat(env2, env, env2_size);
             }
 
             index++;
@@ -939,8 +939,8 @@ char* readline_file_completion(const char* text, int rstat)
                         char buf[PATH_MAX];
 
                         struct stat _stat;
-                        strncpy(buf, string_c_str(gEditingDir), PATH_MAX);
-                        strncat(buf, entry->d_name, PATH_MAX);
+                        xstrncpy(buf, string_c_str(gEditingDir), PATH_MAX);
+                        xstrncat(buf, entry->d_name, PATH_MAX);
                         stat(buf, &_stat);
 
 #if defined(__DARWIN__)
@@ -949,22 +949,22 @@ char* readline_file_completion(const char* text, int rstat)
                         int des_size = strlen(src)*2;
                         char* des = MALLOC(des_size);
                         if(is_all_ascii(src)) {
-                            strncpy(des, src, des_size);
+                            xstrncpy(des, src, des_size);
                         }
                         else {
                             /// コンバート ///
                             if(kanji_convert(src, des, des_size, kUtf8Mac, kUtf8) < 0) {
-                                strncpy(des, src, des_size);
+                                xstrncpy(des, src, des_size);
                             }
                         }
-                        strncpy(buf, des, PATH_MAX);
+                        xstrncpy(buf, des, PATH_MAX);
                         FREE(des);
                         }
 #else
-                        strncpy(buf, entry->d_name, PATH_MAX);
+                        xstrncpy(buf, entry->d_name, PATH_MAX);
 #endif
                         if(S_ISDIR(_stat.st_mode)) {
-                            strncat(buf, "/", PATH_MAX);
+                            xstrncat(buf, "/", PATH_MAX);
                         }
 
                         vector_add(files, STRING_NEW(buf));
@@ -988,8 +988,8 @@ char* readline_file_completion(const char* text, int rstat)
                         char buf[PATH_MAX];
 
                         struct stat _stat;
-                        strncpy(buf, "./", PATH_MAX);
-                        strncat(buf, entry->d_name, PATH_MAX);
+                        xstrncpy(buf, "./", PATH_MAX);
+                        xstrncat(buf, entry->d_name, PATH_MAX);
                         stat(buf, &_stat);
 
 #if defined(__DARWIN__)
@@ -998,22 +998,22 @@ char* readline_file_completion(const char* text, int rstat)
                         int des_size = strlen(src)*2;
                         char* des = MALLOC(des_size);
                         if(is_all_ascii(src)) {
-                            strncpy(des, src, des_size);
+                            xstrncpy(des, src, des_size);
                         }
                         else {
                             /// コンバート ///
                             if(kanji_convert(src, des, des_size, kUtf8Mac, kUtf8) < 0) {
-                                strncpy(des, src, des_size);
+                                xstrncpy(des, src, des_size);
                             }
                         }
-                        strncpy(buf, des, PATH_MAX);
+                        xstrncpy(buf, des, PATH_MAX);
                         FREE(des);
                         }
 #else
-                        strncpy(buf, entry->d_name, PATH_MAX);
+                        xstrncpy(buf, entry->d_name, PATH_MAX);
 #endif
                         if(S_ISDIR(_stat.st_mode)) {
-                            strncat(buf, "/", PATH_MAX);
+                            xstrncat(buf, "/", PATH_MAX);
                         }
                         vector_add(files, STRING_NEW(buf));
                     }
@@ -1033,7 +1033,7 @@ char* readline_file_completion(const char* text, int rstat)
         /// ファイル名の入力がない補完は判定しなくても全てマッチ ///
         if(strcmp(text2, "") == 0) {
             char path[PATH_MAX];
-            strncpy(path, file, PATH_MAX);
+            xstrncpy(path, file, PATH_MAX);
 
             string_obj* tmp2 = STRING_NEW("");
             saphire_get_quoted_fname_readline_ver(path, tmp2);
@@ -1041,8 +1041,8 @@ char* readline_file_completion(const char* text, int rstat)
             string_delete(tmp2);
 
             struct stat stat_;
-            strncpy(path, string_c_str(gEditingDir),  PATH_MAX);
-            strncat(path, file, PATH_MAX);
+            xstrncpy(path, string_c_str(gEditingDir),  PATH_MAX);
+            xstrncat(path, file, PATH_MAX);
             if(stat(path, &stat_) == 0) {
                 if(S_ISDIR(stat_.st_mode)) {
                     rl_completion_append_character= 0;
@@ -1066,15 +1066,15 @@ char* readline_file_completion(const char* text, int rstat)
         else {
             if(!strncmp(text2, file, wordlen)) {
                 char path[PATH_MAX];
-                strncpy(path, file, PATH_MAX);
+                xstrncpy(path, file, PATH_MAX);
 
                 string_obj* tmp2 = STRING_NEW("");
                 saphire_get_quoted_fname(path, tmp2);
                 char* ret = strdup(string_c_str(tmp2));
                 string_delete(tmp2);
 
-                strncpy(path, string_c_str(gEditingDir), PATH_MAX);
-                strncat(path, file, PATH_MAX);
+                xstrncpy(path, string_c_str(gEditingDir), PATH_MAX);
+                xstrncat(path, file, PATH_MAX);
                 struct stat stat_;
                 if(stat(path, &stat_) == 0) {
                     if(S_ISDIR(stat_.st_mode)) {
@@ -2053,8 +2053,8 @@ static BOOL readline_select_file_read(vector_obj* v, char* path)
     struct dirent* entry;
     while(entry = readdir(dir)) {
         char fpath[PATH_MAX];
-        strncpy(fpath, path, PATH_MAX);
-        strncat(fpath, entry->d_name, PATH_MAX);
+        xstrncpy(fpath, path, PATH_MAX);
+        xstrncat(fpath, entry->d_name, PATH_MAX);
 
         struct stat stat_;
         memset(&stat_, 0, sizeof(struct stat));
@@ -2103,7 +2103,7 @@ static void str_cut2(enum eKanjiCode code, char* mbs, int termsize, char* dest_m
 
             n = wcswidth(tmp, wcslen(tmp));
             if(n < 0) {
-                strncpy(dest_mbs, "?????", dest_byte);
+                xstrncpy(dest_mbs, "?????", dest_byte);
 
                 FREE(wcs);
                 FREE(tmp);
@@ -2167,10 +2167,10 @@ static int readline_select_file(int count, int key)
     vector_obj* v = VECTOR_NEW(10);
     char cwd_path[PATH_MAX];
     mygetcwd(cwd_path, PATH_MAX);
-    strncat(cwd_path, "/", PATH_MAX);
+    xstrncat(cwd_path, "/", PATH_MAX);
 
     char current_dir[PATH_MAX];
-    strncpy(current_dir, cwd_path, PATH_MAX);
+    xstrncpy(current_dir, cwd_path, PATH_MAX);
     readline_select_file_read(v, current_dir);
 
     vector_obj* mark_files = VECTOR_NEW(10);
@@ -2205,8 +2205,8 @@ static int readline_select_file(int count, int key)
                 int x = ((n-page*4*(maxy-1)) % 4)*maxx/4;
 
                 char full_path[PATH_MAX];
-                strncpy(full_path, current_dir, PATH_MAX);
-                strncat(full_path, string_c_str(file->mName), PATH_MAX);
+                xstrncpy(full_path, current_dir, PATH_MAX);
+                xstrncat(full_path, string_c_str(file->mName), PATH_MAX);
 
                 BOOL marked = FALSE;
                 int i;
@@ -2264,8 +2264,8 @@ static int readline_select_file(int count, int key)
                 string_obj* cursor_mfile = NULL;
 
                 char cursor_path[PATH_MAX];
-                strncpy(cursor_path, current_dir, PATH_MAX);
-                strncat(cursor_path, string_c_str(cursor_file->mName), PATH_MAX);
+                xstrncpy(cursor_path, current_dir, PATH_MAX);
+                xstrncat(cursor_path, string_c_str(cursor_file->mName), PATH_MAX);
 
                 int i;
                 for(i=0; i<vector_size(mark_files); i++) {
@@ -2289,7 +2289,7 @@ static int readline_select_file(int count, int key)
                 cursor++;
             }
             else if(key == '\\') {
-                strncpy(current_dir, "/", PATH_MAX);
+                xstrncpy(current_dir, "/", PATH_MAX);
 
                 int i;
                 for(i=0; i<vector_size(v); i++) {
@@ -2307,8 +2307,8 @@ static int readline_select_file(int count, int key)
                     /// 現在のカレントディレクトリのパスなら
                     /// ディレクトリ名を取る
                     char cursor_path[PATH_MAX];
-                    strncpy(cursor_path, current_dir, PATH_MAX);
-                    strncat(cursor_path, string_c_str(cursor_file->mName), PATH_MAX);
+                    xstrncpy(cursor_path, current_dir, PATH_MAX);
+                    xstrncat(cursor_path, string_c_str(cursor_file->mName), PATH_MAX);
 
                     /// カレントのファイル、子ディレクトリのファイルなら
                     /// 相対ディレクトリ
@@ -2336,7 +2336,7 @@ static int readline_select_file(int count, int key)
                     int j;
                     for(j=0; j<vector_size(mark_files); j++) {
                         char full_path[PATH_MAX];
-                        strncpy(full_path
+                        xstrncpy(full_path
                             , string_c_str(vector_item(mark_files, j))
                             , PATH_MAX);
 
@@ -2382,10 +2382,9 @@ static int readline_select_file(int count, int key)
                     if(correct_path(current_dir
                             , string_c_str(cursor_file->mName), path2, PATH_MAX)) 
                     {
-                        strncpy(current_dir, path2
-                            , PATH_MAX);
+                        xstrncpy(current_dir, path2, PATH_MAX);
                         if(current_dir[strlen(current_dir)-1] != '/') {
-                            strncat(current_dir, "/", PATH_MAX);
+                            xstrncat(current_dir, "/", PATH_MAX);
                         }
 
                         int i;
@@ -2402,7 +2401,7 @@ static int readline_select_file(int count, int key)
             else if(key == 8 || key == KEY_BACKSPACE) {    // CTRL-H
                 char parent_path[PATH_MAX];
                 parentname(parent_path, PATH_MAX, current_dir);
-                strncpy(current_dir, parent_path, PATH_MAX);
+                xstrncpy(current_dir, parent_path, PATH_MAX);
 
                 int i;
                 for(i=0; i<vector_size(v); i++) {
