@@ -30,6 +30,9 @@ int correct_path(char* current_path, char* path, char* path2, int path2_size);
 
 char* mystrcasestr(const char *haystack, const char *needle); // 部分文字列を返す
 
+char* xstrncpy(char* src, char* des, int size);
+char* xstrncat(char* src, char* des, int size);
+
 
 #endif
 
