@@ -364,7 +364,7 @@ int kanji_convert(char* input_buf, char* output_buf, size_t output_buf_size, enu
     size_t bufsz_out;
 
     if(strlen(input_buf) == 0) {
-        strncpy(output_buf, input_buf, output_buf_size);
+        xstrncpy(output_buf, input_buf, output_buf_size);
     }
     else {
         if(is_all_ascii(input_buf)
@@ -374,7 +374,7 @@ int kanji_convert(char* input_buf, char* output_buf, size_t output_buf_size, enu
             || output_kanji_encode_type < 0
             || output_kanji_encode_type >= kUnknown)
         {
-            strncpy(output_buf, input_buf, output_buf_size);
+            xstrncpy(output_buf, input_buf, output_buf_size);
             return 0;
         }
         
